[
  (input_block)
  (subblock) 
  (geom_block)
  (compound_script)
  (compound_step_block)
  (compound_for_loop)
  (compound_if_block)
] @indent.begin

[
  (input_block)
  (subblock) 
  (geom_block)
  (compound_script)
  (compound_step_block)
  (compound_for_loop)
  (compound_if_block)
] @indent.end

"*" @indent.end